/*
 * The MIT License
 *
 * Copyright 2021 Sebastian Schauer.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package sudoku.model.games;

import sudoku.controller.GameController;
import sudoku.model.board.Area;
import sudoku.model.board.Sudoku;

/**
 * A regular sudoku.
 * 
 * @author Sebastian Schauer
 */
public class RegularSudoku extends Sudoku {

    public RegularSudoku(int size, GameController gc) {
        super(size, gc);
        type = GameType.Regular;
        for (int i = 0; i < size; i++) {
            Area row = new Area(size);
            Area col = new Area(size);
            Area sqa = new Area(size);
            for (int j = 0; j < size; j++) {
                row.addCell(cells[i][j]);
                col.addCell(cells[j][i]);
                sqa.addCell(cells[(i / root) * root + (j % root)][(i % root) * root + (j / root)]);
            }
            areas.add(row);
            areas.add(col);
            areas.add(sqa);
        }
    }
    
    /**
     * Copies this sudoku.
     * @return The copy
     */
    @Override
    public Sudoku copy() {
        return super.copy(new RegularSudoku(size, myGC));
    }
}
